import React, { useEffect, useState } from "react";
import {
  Button,
  Card,
  Col,
  Input,
  Row,
  Tabs,
  Form,
  message,
  Modal,
  Select,
} from "antd";
import {
  FilterOutlined,
  PlusSquareOutlined,
  DownloadOutlined,
} from "@ant-design/icons";
import { BreadcumbComponent } from "../../component/BreadcumbComponent";
import { useStore } from "../../utils/useStore";
import { observer } from "mobx-react-lite";
import { SupplierComponent } from "../../component/SupplierComponent";
import { LINKS } from "../../routes/app";

const { TabPane } = Tabs;
const { Search } = Input;
const { Option } = Select;

export const Supplier = observer(() => {
  const [isLoading, setIsLoading] = useState(false);
  const [confirmLoading, setConfirmLoading] = useState(false);
  const [form] = Form.useForm();
  const store = useStore();

  useEffect(() => {
    const init = async () => {
      try {
        setIsLoading(true);
        //await store.supplier.getDataCategories();
        await store.supplier.getData();
        setIsLoading(false);
      } catch (e) {
        setIsLoading(false);
      }
    };

    init();
  }, []);

  const routeData = [
    {
      route: LINKS.HOME,
      name: "Home",
    },
    {
      route: LINKS.SUPPLIER,
      name: <span style={{ fontWeight: "bold" }}>Supplier</span>,
    },
  ];

  return (
    <div className={["ppob-container"].join(" ")}>
      <BreadcumbComponent data={routeData} />
      <Card>
        <Row style={{ marginBottom: 20 }}>
          {/* <Col span={12}>
            <Button>
              <FilterOutlined />
              Filter
            </Button>
          </Col> */}
          <Col span={24} style={{ textAlign: "right" }}>
            <Search
              placeholder="input search text"
              style={{
                width: store.ui.mediaQuery.isMobile ? 160 : 200,
                marginRight: store.ui.mediaQuery.isMobile ? 0 : 10,
                marginBottom: store.ui.mediaQuery.isMobile ? 10 : 0,
              }}
              onSearch={(value) => console.log(value)}
            />
            <Button
              onClick={() => (store.supplier.visibleModalSupplier = true)}
            >
              <PlusSquareOutlined /> New
            </Button>
          </Col>
        </Row>
        <SupplierComponent />
      </Card>
    </div>
  );
});
